"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const yargs = tslib_1.__importStar(require("yargs"));
const errors_1 = require("../errors");
const search_config_1 = require("./search-config");
const argv = yargs.argv;
const { cwd, config: rulePath } = search_config_1.searchConfig(argv, "verdafile.js");
process.chdir(cwd);
main(rulePath).catch((e) => {
    const ext = errors_1.getExtErrorProps(e);
    if (!ext) {
        console.error("");
        console.error(e);
    }
    process.exit(1);
});
async function main(rulePath) {
    const _sessionModule = await Promise.resolve().then(() => tslib_1.__importStar(require(rulePath)));
    const _session = _sessionModule.default || _sessionModule;
    if (!_session.loadJournal || !_session.start) {
        throw new Error(`Configuration ${rulePath} is not default-exporting a Verda configuration`);
    }
    const session = _session;
    session.bindConfig({ rulePath, cwd, ...argv });
    await session.loadJournal();
    await session.createSelfTrackingRule(session.userSelfTrackingGoal);
    const userCancel = () => {
        session.userCancelSync();
        process.exit(1);
    };
    process.once("SIGINT", userCancel).once("SIGTERM", userCancel);
    try {
        await session.start(...argv._);
    }
    finally {
        session.saveJournalSync();
    }
}
