"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hashSmallFile = exports.hashFile = void 0;
const tslib_1 = require("tslib");
const cp = tslib_1.__importStar(require("child_process"));
const crypto = tslib_1.__importStar(require("crypto"));
const fs = tslib_1.__importStar(require("fs-extra"));
const os = tslib_1.__importStar(require("os"));
const path = tslib_1.__importStar(require("path"));
const semaphore_async_await_1 = tslib_1.__importDefault(require("semaphore-async-await"));
const jobs = os.cpus().length;
const semaphore = new semaphore_async_await_1.default(jobs);
function nodejsExitPromise(p, returnValue, err) {
    return new Promise(function (resolve, reject) {
        p.on("exit", function (code, signal) {
            const e = err();
            const r = returnValue();
            if (signal || code || e) {
                return reject(e);
            }
            else {
                return resolve(r);
            }
        });
    });
}
function hashFileChildProcessImpl(fileName) {
    let returnValue = null;
    let errorThrown = null;
    let proc = cp.spawn(process.execPath, [path.join(__dirname, "guest.js")], {
        stdio: ["pipe", "pipe", "pipe", "ipc"],
    });
    proc.on("message", function (message) {
        if (!message.directive) {
            errorThrown = new Error("IPC Error " + message);
        }
        switch (message.directive) {
            case "ready":
                proc.send({ directive: "compute", path: fileName });
                break;
            case "return":
                returnValue = message.result;
                proc.send({ directive: "over" });
                break;
            case "error":
                console.error("<IPC Error>", message.reason);
                errorThrown = new Error(message.reason);
                break;
            case "callError":
                console.error("<Failure>", message.message || message.reason);
                errorThrown = new Error(message.message || message.reason);
                break;
            default:
                errorThrown = new Error("<IPC Error> " + message);
                break;
        }
    });
    return nodejsExitPromise(proc, () => returnValue, () => errorThrown);
}
async function hashFile(path) {
    try {
        await semaphore.acquire();
        const h = await hashFileChildProcessImpl(path);
        semaphore.release();
        return h;
    }
    catch (e) {
        semaphore.release();
        throw e;
    }
}
exports.hashFile = hashFile;
async function hashSmallFile(path) {
    return new Promise((resolve, reject) => {
        let sum = crypto.createHash("sha1");
        let fileStream = fs.createReadStream(path);
        fileStream.on("error", function (err) {
            return reject(err);
        });
        fileStream.on("data", function (chunk) {
            try {
                sum.update(chunk);
            }
            catch (ex) {
                return reject(ex);
            }
        });
        fileStream.on("end", function () {
            return resolve(sum.digest("hex"));
        });
    });
}
exports.hashSmallFile = hashSmallFile;
