"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultStylizer = exports.jsCallStyle = exports.commandStylizer = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const util = tslib_1.__importStar(require("util"));
exports.commandStylizer = {
    trail: "...",
    styledTrail: chalk_1.default.gray("..."),
    joiner(line) {
        return line > 0 ? "|" : "";
    },
    escape(term, lineNo, termNo) {
        return typeof term === "string"
            ? /[ ']/.test(term)
                ? "'" + term.replace(/[\\']/g, "\\$&") + "'"
                : term
            : util.inspect(term) || "";
    },
    stylize(term, lineNo, termNo, text, slicedText) {
        if (termNo === -1)
            return chalk_1.default.cyanBright(slicedText);
        if (termNo === 0)
            return chalk_1.default.blueBright.underline(slicedText);
        if (typeof term !== "string")
            return slicedText;
        if (/^-/.test(text))
            return chalk_1.default.yellow(slicedText);
        if (/^'/.test(text))
            return chalk_1.default.green(slicedText);
        return slicedText;
    }
};
exports.jsCallStyle = {
    trail: "...",
    styledTrail: chalk_1.default.gray("..."),
    joiner(line) {
        return "";
    },
    escape(term, lineNo, termNo) {
        return JSON.stringify(term) || "";
    },
    stylize(term, lineNo, termNo, text, slicedText) {
        if (termNo === 0)
            return chalk_1.default.blue.underline(slicedText);
        return slicedText;
    }
};
exports.defaultStylizer = {
    trail: "...",
    styledTrail: chalk_1.default.gray("..."),
    joiner(line) {
        return "";
    },
    escape(term, lineNo, termNo) {
        return term + "";
    },
    stylize(term, lineNo, termNo, text, slicedText) {
        return slicedText;
    }
};
